@@ -41,7 +41,7 @@ class Subscription(NamespacedResource):
         self.node_selector = node_selector
         self.tolerations = tolerations
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             self.res.update({
